@@ -570,7 +570,7 @@ AJAX.registerOnload('sql.js', function () {
         var $form = $button.parent('form');
         var submitData = $form.serialize() + '&ajax_request=true&ajax_page_request=true&submit_mult=' + $button.val();
         PMA_ajaxShowMessage();
-        $.get($form.attr('action'), submitData, AJAX.responseHandler);
+        $.post($form.attr('action'), submitData, AJAX.responseHandler);
     });
 }); // end $()
 
