@@ -465,16 +465,18 @@ class ImportSql extends ImportPlugin
             );
         }
 
-        //Commit any possible data in buffers
-        PMA_importRunQuery(
-            $this->_stringFctToUse['substr'](
+        if (! $timeout_passed) {
+            //Commit any possible data in buffers
+            PMA_importRunQuery(
+                $this->_stringFctToUse['substr'](
+                    $this->_data,
+                    $this->_queryBeginPosition
+                ), //Query to execute
                 $this->_data,
-                $this->_queryBeginPosition
-            ), //Query to execute
-            $this->_data,
-            false,
-            $sql_data
-        );
+                false,
+                $sql_data
+            );
+        }
         PMA_importRunQuery('', '', false, $sql_data);
     }
 
